@@ -1641,14 +1641,14 @@ Socket::Socket()
     ioerr = 0;
 }
 
-Socket::Socket(socket_t s)
+Socket::Socket(const socket_t s)
 {
     so = s;
     iowait = Timer::inf;
     ioerr = 0;
 }
 
-Socket::Socket(struct addrinfo *addr)
+Socket::Socket(const struct addrinfo *addr)
 {
 #ifdef  _MSWINDOWS_
     init();
@@ -2662,7 +2662,7 @@ bool Socket::connected(void) const
     return true;
 }
 
-bool Socket::is_pending(unsigned qio) const
+bool Socket::is_pending(unsigned qio)
 {
     if(pending() >= qio)
         return true;
