@@ -162,8 +162,8 @@ size_t utf8::count(const char *string)
     if(!string)
         return 0;
 
-    while(*string && (codesize = size(string) != 0)) {
-        pos += codesize;
+    while(*string && (codesize = size(string)) != 0) {
+        ++pos;
         string += codesize;
     }
 
