@@ -20,6 +20,8 @@
 static const unsigned char *_salt = NULL;
 static unsigned _rounds = 1;
 
+namespace ucommon {
+
 void Cipher::Key::assign(const char *text, size_t size, const unsigned char *salt, unsigned rounds)
 {
     keysize = 0;
@@ -89,3 +91,4 @@ size_t Cipher::pad(const unsigned char *data, size_t size)
     return 0;
 }
 
+} // namespace ucommon
