@@ -17,6 +17,8 @@
 
 #include "local.h"
 
+namespace ucommon {
+
 void Random::seed(void)
 {
     secure::init();
@@ -57,3 +59,4 @@ bool Random::status(void)
     return false;
 }
 
+} // namespace ucommon
